/*
 * encoder.h for miniD pre OLED
 *
 * Rotary encoder functions including encoder rotation and button push.
 *
 * Initial version: 20/12/2017
 * Author: Tomi Nihtila, nihtila.com
 */


#ifndef ENCODER_H_
#define ENCODER_H_



// Define this if encoder direction is opposite
#define ENC_REVERSE


// ROTARY ENCODER
// Keeps track of encoder related variables
//typedef struct encoderSt {
typedef struct {
	const signed char luTable[16];			// Look-up table (LUT) to determine encoder direction
	volatile unsigned char ab;              // Current encoder state
	volatile signed char counter;           // Counts encoder rotation, sum of consecutive LUT readings
	volatile unsigned char butState;        // Previous button state
	volatile unsigned int countBut;         // Counts how long button has been pushed
	const unsigned int intervalShortBut;	// Constant for determining short button push (*TICK)
	const unsigned int intervalLongBut;		// Constant for long button push (*TICK)
} encoderSt;

extern encoderSt encoder;


void encoderButtonISR(void);				// used inside ISR in main.c
void encoderRotateISR(unsigned char abOld);	// used inside ISR in main.c
void encoderChange(void);					// called in the main loop in main.c
void encoderTimeout(void);					// cheduled event function
void encoderButtonPushCount(void);			// scheduled event function
void encoderShortButtonPush(void);
void encoderLongButtonPush(void);

#endif /* ENCODER_H_ */